.. Last updated Thu Aug  9 15:29:53 BST 2012

Modules
=======

Designs
-------

.. automodule:: designs
   :members:

Graphs
------

.. automodule:: graphs
   :members:

Hall
----

.. automodule:: hall
   :members:

Output
------

.. automodule:: output
   :members:

Utils
-----

.. automodule:: utils
   :members:

